@@ -24,10 +24,10 @@
 #include "empathy-individual-menu.h"
 
 #include <glib/gi18n-lib.h>
+#include <tp-account-widgets/tpaw-camera-monitor.h>
 
 #include "empathy-account-selector-dialog.h"
 #include "empathy-call-utils.h"
-#include "empathy-camera-monitor.h"
 #include "empathy-chatroom-manager.h"
 #include "empathy-gtk-enum-types.h"
 #include "empathy-images.h"
@@ -49,13 +49,15 @@
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyIndividualMenu)
 
 typedef struct {
+  gchar *active_group; /* may be NULL */
   FolksIndividual *individual; /* owned */
   EmpathyIndividualFeatureFlags features;
   EmpathyIndividualStore *store; /* may be NULL */
 } EmpathyIndividualMenuPriv;
 
 enum {
-  PROP_INDIVIDUAL = 1,
+  PROP_ACTIVE_GROUP = 1,
+  PROP_INDIVIDUAL,
   PROP_FEATURES,
   PROP_STORE,
 };
@@ -87,7 +89,7 @@ static GtkWidget * empathy_individual_add_menu_item_new (
 static GtkWidget * empathy_individiual_block_menu_item_new (
     FolksIndividual *individual);
 static GtkWidget * empathy_individiual_remove_menu_item_new (
-    FolksIndividual *individual);
+    EmpathyIndividualMenu *self);
 
 static void
 individual_menu_add_personas (GtkMenuShell *menu,
@@ -294,7 +296,7 @@ find_phone_accounts (void)
           TP_CONNECTION_STATUS_CONNECTED)
         continue;
 
-      if (!empathy_account_has_uri_scheme_tel (account))
+      if (!tp_account_associated_with_uri_scheme (account, "tel"))
         continue;
 
       found = g_list_prepend (found, g_object_ref (account));
@@ -685,13 +687,16 @@ enum
   REMOVE_DIALOG_RESPONSE_CANCEL = 0,
   REMOVE_DIALOG_RESPONSE_DELETE,
   REMOVE_DIALOG_RESPONSE_DELETE_AND_BLOCK,
+  REMOVE_DIALOG_RESPONSE_REMOVE_FROM_GROUP
 };
 
 static int
 remove_dialog_show (const gchar *message,
     const gchar *secondary_text,
+    gboolean show_remove_from_group,
     gboolean block_button,
-    GdkPixbuf *avatar)
+    GdkPixbuf *avatar,
+    const gchar *active_group)
 {
   GtkWidget *dialog;
   gboolean res;
@@ -706,6 +711,23 @@ remove_dialog_show (const gchar *message,
       gtk_widget_show (image);
     }
 
+  if (show_remove_from_group)
+    {
+      GtkWidget *button;
+      gchar *button_text = g_strdup_printf (_("Remove from _Group \'%s\'"),
+          active_group);
+
+      /* gtk_dialog_add_button() doesn't allow us to pass a string with a
+       * mnemonic so we have to create the button manually. */
+      button = gtk_button_new_with_mnemonic (button_text);
+      g_free (button_text);
+
+      gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
+          REMOVE_DIALOG_RESPONSE_REMOVE_FROM_GROUP);
+
+      gtk_widget_show (button);
+    }
+
   if (block_button)
     {
       GtkWidget *button;
@@ -735,12 +757,32 @@ remove_dialog_show (const gchar *message,
   return res;
 }
 
+static void
+individual_removed_from_group_cb (GObject *source_object,
+    GAsyncResult *res,
+    gpointer user_data)
+{
+  GError *error = NULL;
+  FolksIndividual *individual = FOLKS_INDIVIDUAL (source_object);
+
+  folks_group_details_change_group_finish (
+      FOLKS_GROUP_DETAILS (individual), res, &error);
+  if (error != NULL)
+    {
+      DEBUG ("Individual could not be removed from group: %s",
+          error->message);
+      g_error_free (error);
+    }
+}
+
 static void
 remove_got_avatar (GObject *source_object,
     GAsyncResult *result,
     gpointer user_data)
 {
   FolksIndividual *individual = FOLKS_INDIVIDUAL (source_object);
+  EmpathyIndividualMenu *self = EMPATHY_INDIVIDUAL_MENU (user_data);
+  EmpathyIndividualMenuPriv *priv = GET_PRIV (self);
   GdkPixbuf *avatar;
   EmpathyIndividualManager *manager;
   gchar *text;
@@ -749,6 +791,8 @@ remove_got_avatar (GObject *source_object,
   gboolean can_block;
   GError *error = NULL;
   gint res;
+  gboolean show_remove_from_group;
+  GeeSet *groups;
 
   avatar = empathy_pixbuf_avatar_from_individual_scaled_finish (individual,
       result, &error);
@@ -762,6 +806,10 @@ remove_got_avatar (GObject *source_object,
   /* We couldn't retrieve the avatar, but that isn't a fatal error,
    * so we still display the remove dialog. */
 
+  groups = folks_group_details_get_groups (FOLKS_GROUP_DETAILS (individual));
+  show_remove_from_group =
+      gee_collection_get_size (GEE_COLLECTION (groups)) > 1;
+
   personas = folks_individual_get_personas (individual);
 
   persona_count = gee_collection_get_size (GEE_COLLECTION (personas));
@@ -795,7 +843,15 @@ remove_got_avatar (GObject *source_object,
   manager = empathy_individual_manager_dup_singleton ();
   can_block = empathy_individual_manager_supports_blocking (manager,
       individual);
-  res = remove_dialog_show (_("Removing contact"), text, can_block, avatar);
+  res = remove_dialog_show (_("Removing contact"), text,
+      show_remove_from_group, can_block, avatar, priv->active_group);
+
+  if (res == REMOVE_DIALOG_RESPONSE_REMOVE_FROM_GROUP)
+    {
+      folks_group_details_change_group (FOLKS_GROUP_DETAILS (individual),
+          priv->active_group, false, individual_removed_from_group_cb, NULL);
+      goto finally;
+    }
 
   if (res == REMOVE_DIALOG_RESPONSE_DELETE ||
       res == REMOVE_DIALOG_RESPONSE_DELETE_AND_BLOCK)
@@ -818,29 +874,33 @@ remove_got_avatar (GObject *source_object,
  finally:
   g_free (text);
   g_object_unref (manager);
+  g_object_unref (self);
 }
 
 static void
 remove_activate_cb (GtkMenuItem *menuitem,
-    FolksIndividual *individual)
+    EmpathyIndividualMenu *self)
 {
-  empathy_pixbuf_avatar_from_individual_scaled_async (individual,
-      48, 48, NULL, remove_got_avatar, NULL);
+  EmpathyIndividualMenuPriv *priv = GET_PRIV (self);
+
+  empathy_pixbuf_avatar_from_individual_scaled_async (priv->individual,
+      48, 48, NULL, remove_got_avatar, g_object_ref (self));
 }
 
 static GtkWidget *
-empathy_individiual_remove_menu_item_new (FolksIndividual *individual)
+empathy_individiual_remove_menu_item_new (EmpathyIndividualMenu *self)
 {
   GeeSet *personas;
   GeeIterator *iter;
   gboolean can_remove = FALSE;
   GtkWidget *item, *image;
+  EmpathyIndividualMenuPriv *priv = GET_PRIV (self);
 
   /* If any of the Individual's personas can be removed, add an option to
    * remove. This will act as a best-effort option. If any Personas cannot be
    * removed from the server, then this option will just be inactive upon
    * subsequent menu openings */
-  personas = folks_individual_get_personas (individual);
+  personas = folks_individual_get_personas (priv->individual);
   iter = gee_iterable_iterator (GEE_ITERABLE (personas));
   while (!can_remove && gee_iterator_next (iter))
     {
@@ -865,7 +925,7 @@ empathy_individiual_remove_menu_item_new (FolksIndividual *individual)
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
   g_signal_connect (item, "activate",
-      G_CALLBACK (remove_activate_cb), individual);
+      G_CALLBACK (remove_activate_cb), self);
 
   return item;
 }
@@ -873,7 +933,7 @@ empathy_individiual_remove_menu_item_new (FolksIndividual *individual)
 static void
 constructed (GObject *object)
 {
-  EmpathyIndividualMenu *self = (EmpathyIndividualMenu *) object;
+  EmpathyIndividualMenu *self = EMPATHY_INDIVIDUAL_MENU (object);
   EmpathyIndividualMenuPriv *priv = GET_PRIV (object);
   GtkMenuShell *shell;
   GtkWidget *item;
@@ -1014,7 +1074,7 @@ constructed (GObject *object)
 
   /* Separator & Remove */
   if (features & EMPATHY_INDIVIDUAL_FEATURE_REMOVE &&
-      (item = empathy_individiual_remove_menu_item_new (individual)) != NULL) {
+      (item = empathy_individiual_remove_menu_item_new (self)) != NULL) {
     GtkWidget *sep;
 
     sep = gtk_separator_menu_item_new ();
@@ -1038,6 +1098,9 @@ get_property (GObject *object,
 
   switch (param_id)
     {
+      case PROP_ACTIVE_GROUP:
+        g_value_set_string (value, priv->active_group);
+        break;
       case PROP_INDIVIDUAL:
         g_value_set_object (value, priv->individual);
         break;
@@ -1065,6 +1128,10 @@ set_property (GObject *object,
 
   switch (param_id)
     {
+      case PROP_ACTIVE_GROUP:
+        g_assert (priv->active_group == NULL); /* construct only */
+        priv->active_group = g_value_dup_string (value);
+        break;
       case PROP_INDIVIDUAL:
         priv->individual = g_value_dup_object (value);
         break;
@@ -1091,6 +1158,16 @@ dispose (GObject *object)
   G_OBJECT_CLASS (empathy_individual_menu_parent_class)->dispose (object);
 }
 
+static void
+finalize (GObject *object)
+{
+  EmpathyIndividualMenuPriv *priv = GET_PRIV (object);
+
+  g_free (priv->active_group);
+
+  G_OBJECT_CLASS (empathy_individual_menu_parent_class)->finalize (object);
+}
+
 static void
 empathy_individual_menu_class_init (EmpathyIndividualMenuClass *klass)
 {
@@ -1100,6 +1177,19 @@ empathy_individual_menu_class_init (EmpathyIndividualMenuClass *klass)
   object_class->get_property = get_property;
   object_class->set_property = set_property;
   object_class->dispose = dispose;
+  object_class->finalize = finalize;
+
+  /**
+   * gchar *:active-group:
+   *
+   * The group the selected roster-contact widget belongs, or NULL.
+   */
+  g_object_class_install_property (object_class, PROP_ACTIVE_GROUP,
+      g_param_spec_string ("active-group",
+          "Active group",
+          "The group the selected roster-contact widget belongs, or NULL",
+          NULL,
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
   /**
    * EmpathyIndividualMenu:individual:
@@ -1138,6 +1228,7 @@ empathy_individual_menu_class_init (EmpathyIndividualMenuClass *klass)
 
 GtkWidget *
 empathy_individual_menu_new (FolksIndividual *individual,
+    const gchar *active_group,
     EmpathyIndividualFeatureFlags features,
     EmpathyIndividualStore *store)
 {
@@ -1147,6 +1238,7 @@ empathy_individual_menu_new (FolksIndividual *individual,
   g_return_val_if_fail (features != EMPATHY_INDIVIDUAL_FEATURE_NONE, NULL);
 
   return g_object_new (EMPATHY_TYPE_INDIVIDUAL_MENU,
+      "active-group", active_group,
       "individual", individual,
       "features", features,
       "store", store,
@@ -1319,7 +1411,7 @@ empathy_individual_video_call_menu_item_new (FolksIndividual *individual)
 {
   GtkWidget *item;
   GtkWidget *image;
-  EmpathyCameraMonitor *monitor;
+  TpawCameraMonitor *monitor;
 
   g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), NULL);
 
@@ -1336,7 +1428,7 @@ empathy_individual_video_call_menu_item_new (FolksIndividual *individual)
   /* Only follow available cameras if the contact can do Video calls */
   if (gtk_widget_get_sensitive (item))
     {
-      monitor = empathy_camera_monitor_dup_singleton ();
+      monitor = tpaw_camera_monitor_dup_singleton ();
       g_object_set_data_full (G_OBJECT (item),
           "monitor", monitor, g_object_unref);
       g_object_bind_property (monitor, "available", item, "sensitive",
