@@ -28,6 +28,8 @@
 #include "empathy-individual-view.h"
 
 #include <glib/gi18n-lib.h>
+#include <tp-account-widgets/tpaw-pixbuf-utils.h>
+#include <tp-account-widgets/tpaw-utils.h>
 
 #include "empathy-cell-renderer-activatable.h"
 #include "empathy-cell-renderer-expander.h"
@@ -1160,12 +1162,12 @@ individual_view_group_icon_cell_data_func (GtkTreeViewColumn *tree_column,
 
   if (!tp_strdiff (name, EMPATHY_INDIVIDUAL_STORE_FAVORITE))
     {
-      pixbuf = empathy_pixbuf_from_icon_name ("emblem-favorite",
+      pixbuf = tpaw_pixbuf_from_icon_name ("emblem-favorite",
           GTK_ICON_SIZE_MENU);
     }
   else if (!tp_strdiff (name, EMPATHY_INDIVIDUAL_STORE_PEOPLE_NEARBY))
     {
-      pixbuf = empathy_pixbuf_from_icon_name ("im-local-xmpp",
+      pixbuf = tpaw_pixbuf_from_icon_name ("im-local-xmpp",
           GTK_ICON_SIZE_MENU);
     }
 
@@ -1327,7 +1329,7 @@ individual_view_start_search_cb (EmpathyIndividualView *view,
 }
 
 static void
-individual_view_search_text_notify_cb (EmpathyLiveSearch *search,
+individual_view_search_text_notify_cb (TpawLiveSearch *search,
     GParamSpec *pspec,
     EmpathyIndividualView *view)
 {
@@ -1420,7 +1422,7 @@ individual_view_search_key_navigation_cb (GtkWidget *search,
 }
 
 static void
-individual_view_search_hide_cb (EmpathyLiveSearch *search,
+individual_view_search_hide_cb (TpawLiveSearch *search,
     EmpathyIndividualView *view)
 {
   EmpathyIndividualViewPriv *priv = GET_PRIV (view);
@@ -1489,7 +1491,7 @@ individual_view_search_hide_cb (EmpathyLiveSearch *search,
 }
 
 static void
-individual_view_search_show_cb (EmpathyLiveSearch *search,
+individual_view_search_show_cb (TpawLiveSearch *search,
     EmpathyIndividualView *view)
 {
   /* block expand or collapse handlers during expand all, they would
@@ -1595,7 +1597,7 @@ individual_view_row_has_child_toggled_cb (GtkTreeModel *model,
       EMPATHY_INDIVIDUAL_STORE_COL_NAME, &name,
       -1);
 
-  if (!is_group || EMP_STR_EMPTY (name))
+  if (!is_group || TPAW_STR_EMPTY (name))
     {
       g_free (name);
       return;
@@ -1639,7 +1641,7 @@ individual_view_is_visible_individual (EmpathyIndividualView *self,
     guint event_count)
 {
   EmpathyIndividualViewPriv *priv = GET_PRIV (self);
-  EmpathyLiveSearch *live = EMPATHY_LIVE_SEARCH (priv->search_widget);
+  TpawLiveSearch *live = TPAW_LIVE_SEARCH (priv->search_widget);
   GeeSet *personas;
   GeeIterator *iter;
   gboolean is_favorite;
@@ -1691,8 +1693,8 @@ individual_view_is_visible_individual (EmpathyIndividualView *self,
   }
 
   return empathy_individual_match_string (individual,
-      empathy_live_search_get_text (live),
-      empathy_live_search_get_words (live));
+      tpaw_live_search_get_text (live),
+      tpaw_live_search_get_words (live));
 }
 
 static gchar *
@@ -2359,7 +2361,7 @@ individual_view_group_remove_activate_cb (GtkMenuItem *menuitem,
       text =
           g_strdup_printf (_("Do you really want to remove the group '%s'?"),
           group);
-      parent = empathy_get_toplevel_window (GTK_WIDGET (view));
+      parent = tpaw_get_toplevel_window (GTK_WIDGET (view));
       if (individual_view_remove_dialog_show (parent, _("Removing group"),
               text) == REMOVE_DIALOG_RESPONSE_DELETE)
         {
@@ -2472,8 +2474,8 @@ empathy_individual_view_get_individual_menu (EmpathyIndividualView *view)
   if (!empathy_folks_individual_contains_contact (individual))
     goto out;
 
-  menu = empathy_individual_menu_new (individual, priv->individual_features,
-      priv->store);
+  menu = empathy_individual_menu_new (individual, NULL,
+      priv->individual_features, priv->store);
 
 out:
   g_object_unref (individual);
@@ -2483,7 +2485,7 @@ out:
 
 void
 empathy_individual_view_set_live_search (EmpathyIndividualView *view,
-    EmpathyLiveSearch *search)
+    TpawLiveSearch *search)
 {
   EmpathyIndividualViewPriv *priv = GET_PRIV (view);
 
