@@ -23,6 +23,10 @@
 #include "empathy-individual-widget.h"
 
 #include <glib/gi18n-lib.h>
+#include <tp-account-widgets/tpaw-builder.h>
+#include <tp-account-widgets/tpaw-contactinfo-utils.h>
+#include <tp-account-widgets/tpaw-time.h>
+#include <tp-account-widgets/tpaw-utils.h>
 
 #ifdef HAVE_LIBCHAMPLAIN
 #include <champlain/champlain.h>
@@ -30,11 +34,10 @@
 #endif
 
 #include "empathy-avatar-image.h"
-#include "empathy-contactinfo-utils.h"
 #include "empathy-groups-widget.h"
 #include "empathy-gtk-enum-types.h"
 #include "empathy-location.h"
-#include "empathy-time.h"
+#include "empathy-request-util.h"
 #include "empathy-ui-utils.h"
 #include "empathy-utils.h"
 
@@ -218,6 +221,70 @@ add_row (GtkGrid *grid,
   gtk_widget_show (value);
 }
 
+static gboolean
+channel_name_activated_cb (
+    GtkLabel *label,
+    gchar *uri,
+    TpAccount *account)
+{
+  empathy_join_muc (account, uri, empathy_get_current_action_time ());
+  return TRUE;
+}
+
+static GtkWidget *
+create_channel_list_label (TpAccount *account,
+    GList *info,
+    guint row)
+{
+  GtkWidget *label = NULL;
+  GString *label_markup = g_string_new ("");
+  guint i;
+  GPtrArray *channels;
+  GList *l;
+
+  /* Is there channels? */
+  channels = g_ptr_array_new ();
+
+  for (l = info; l != NULL; l = l->next)
+    {
+      TpContactInfoField *field = l->data;
+
+      if (!tp_strdiff (field->field_name, "x-irc-channel"))
+        g_ptr_array_add (channels, (gpointer) field->field_value[0]);
+    }
+
+  if (channels->len == 0)
+    goto out;
+
+  for (i = 0; i < channels->len; i++)
+    {
+      const gchar *channel_name = g_ptr_array_index (channels, i);
+      /* We abuse the URI of the link to hold the channel name. It seems to
+       * be okay to just use it essentially verbatim, rather than trying to
+       * ensure it's actually a valid URI. */
+      gchar *escaped = g_markup_escape_text (channel_name, -1);
+
+      if (i > 0)
+        g_string_append (label_markup, ", ");
+
+      g_string_append_printf (label_markup, "<a href='%s'>%s</a>",
+          escaped, escaped);
+      g_free (escaped);
+    }
+
+  label = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (label), label_markup->str);
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+
+  g_signal_connect (label, "activate-link",
+      (GCallback) channel_name_activated_cb, account);
+
+out:
+  g_ptr_array_unref (channels);
+  g_string_free (label_markup, TRUE);
+
+  return label;
+}
 static guint
 details_update_show (EmpathyIndividualWidget *self,
     TpContact *contact)
@@ -230,13 +297,13 @@ details_update_show (EmpathyIndividualWidget *self,
   TpAccount *account;
 
   info = tp_contact_dup_contact_info (contact);
-  info = g_list_sort (info, (GCompareFunc) empathy_contact_info_field_cmp);
+  info = g_list_sort (info, (GCompareFunc) tpaw_contact_info_field_cmp);
   for (l = info; l != NULL; l = l->next)
     {
       TpContactInfoField *field = l->data;
       gchar *title;
       const gchar *value;
-      EmpathyContactInfoFormatFunc format;
+      TpawContactInfoFormatFunc format;
       GtkWidget *title_widget, *value_widget;
 
       if (field->field_value == NULL || field->field_value[0] == NULL)
@@ -244,7 +311,7 @@ details_update_show (EmpathyIndividualWidget *self,
 
       value = field->field_value[0];
 
-      if (!empathy_contact_info_lookup_field (field->field_name,
+      if (!tpaw_contact_info_lookup_field (field->field_name,
           NULL, &format))
         {
           DEBUG ("Unhandled ContactInfo field: %s", field->field_name);
@@ -256,7 +323,7 @@ details_update_show (EmpathyIndividualWidget *self,
         continue;
 
       /* Add Title */
-      title = empathy_contact_info_field_label (field->field_name,
+      title = tpaw_contact_info_field_label (field->field_name,
           field->parameters, TRUE);
       title_widget = gtk_label_new (title);
 
@@ -284,8 +351,7 @@ details_update_show (EmpathyIndividualWidget *self,
   conn = tp_contact_get_connection (contact);
   account = tp_connection_get_account (conn);
 
-  channels_label = empathy_contact_info_create_channel_list_label (account,
-      info, n_rows);
+  channels_label = create_channel_list_label (account, info, n_rows);
 
   if (channels_label != NULL)
     {
@@ -593,7 +659,7 @@ location_update (EmpathyIndividualWidget *self)
 
       stamp = g_value_get_int64 (value);
 
-      user_date = empathy_time_to_string_relative (stamp);
+      user_date = tpaw_time_to_string_relative (stamp);
 
       tmp = g_strdup_printf ("<b>%s</b>", _("Location"));
       /* translators: format is "Location, $date" */
@@ -646,7 +712,7 @@ location_update (EmpathyIndividualWidget *self)
           gint64 time_;
 
           time_ = g_value_get_int64 (value);
-          svalue = empathy_time_to_string_utc (time_, _("%B %e, %Y at %R UTC"));
+          svalue = tpaw_time_to_string_utc (time_, _("%B %e, %Y at %R UTC"));
         }
 
       if (svalue != NULL)
@@ -1231,13 +1297,13 @@ notify_presence_cb (gpointer folks_object,
   /* FIXME: Default messages should be moved into libfolks (bgo#627403) */
   message = folks_presence_details_get_presence_message (
       FOLKS_PRESENCE_DETAILS (folks_object));
-  if (EMP_STR_EMPTY (message))
+  if (TPAW_STR_EMPTY (message))
     {
       message = empathy_presence_get_default_message (presence);
     }
 
   if (message != NULL)
-    markup_text = empathy_add_link_markup (message);
+    markup_text = tpaw_add_link_markup (message);
   gtk_label_set_markup (GTK_LABEL (status_label), markup_text);
   g_free (markup_text);
 
@@ -1965,7 +2031,7 @@ empathy_individual_widget_init (EmpathyIndividualWidget *self)
 
   filename = empathy_file_lookup ("empathy-individual-widget.ui",
       "libempathy-gtk");
-  gui = empathy_builder_get_file (filename,
+  gui = tpaw_builder_get_file (filename,
       "scrolled_window_individual", &priv->scrolled_window_individual,
       "viewport_individual", &priv->viewport_individual,
       "vbox_individual_widget", &priv->vbox_individual_widget,
