@@ -67,11 +67,16 @@ struct _EmpathyRosterViewPriv
   gboolean show_groups;
   gboolean empty;
 
-  EmpathyLiveSearch *search;
+  TpawLiveSearch *search;
 
   EmpathyRosterModel *model;
 };
 
+/* Prototypes to break cycles */
+static void remove_from_group (EmpathyRosterView *self,
+    FolksIndividual *individual,
+    const gchar *group);
+
 typedef struct
 {
   guint id;
@@ -345,6 +350,14 @@ add_to_group (EmpathyRosterView *self,
       update_group_widgets (self, roster_group,
           EMPATHY_ROSTER_CONTACT (contact), TRUE);
     }
+
+  if (tp_strdiff (group, NO_GROUP) &&
+      tp_strdiff (group, EMPATHY_ROSTER_MODEL_GROUP_UNGROUPED) &&
+      g_hash_table_size (contacts) == 2 /* 1:Ungrouped and 2:first group */)
+    {
+      remove_from_group (self, individual,
+          EMPATHY_ROSTER_MODEL_GROUP_UNGROUPED);
+    }
 }
 
 static void
@@ -851,8 +864,8 @@ contact_should_be_displayed (EmpathyRosterView *self,
       individual = empathy_roster_contact_get_individual (contact);
 
       return empathy_individual_match_string (individual,
-          empathy_live_search_get_text (self->priv->search),
-          empathy_live_search_get_words (self->priv->search));
+          tpaw_live_search_get_text (self->priv->search),
+          tpaw_live_search_get_words (self->priv->search));
     }
 
   if (self->priv->show_offline)
@@ -1146,6 +1159,7 @@ fire_popup_individual_menu (EmpathyRosterView *self,
 {
   EmpathyRosterContact *contact;
   FolksIndividual *individual;
+  const gchar *active_group;
 
   if (!EMPATHY_IS_ROSTER_CONTACT (child))
     return;
@@ -1153,8 +1167,9 @@ fire_popup_individual_menu (EmpathyRosterView *self,
   contact = EMPATHY_ROSTER_CONTACT (child);
   individual = empathy_roster_contact_get_individual (contact);
 
+  active_group = empathy_roster_contact_get_group (contact);
   g_signal_emit (self, signals[SIG_POPUP_INDIVIDUAL_MENU], 0,
-      individual, button, time);
+      active_group, individual, button, time);
 }
 
 static gboolean
@@ -1347,7 +1362,8 @@ empathy_roster_view_class_init (
       G_SIGNAL_RUN_LAST,
       0, NULL, NULL, NULL,
       G_TYPE_NONE,
-      3, FOLKS_TYPE_INDIVIDUAL, G_TYPE_UINT, G_TYPE_UINT);
+      4, G_TYPE_STRING, FOLKS_TYPE_INDIVIDUAL, G_TYPE_UINT,
+          G_TYPE_UINT);
 
   signals[SIG_EVENT_ACTIVATED] = g_signal_new ("event-activated",
       G_OBJECT_CLASS_TYPE (klass),
@@ -1457,7 +1473,7 @@ search_timeout_cb (EmpathyRosterView *self)
 }
 
 static void
-search_text_notify_cb (EmpathyLiveSearch *search,
+search_text_notify_cb (TpawLiveSearch *search,
     GParamSpec *pspec,
     EmpathyRosterView *self)
 {
@@ -1484,7 +1500,7 @@ search_activate_cb (GtkWidget *search,
 
 void
 empathy_roster_view_set_live_search (EmpathyRosterView *self,
-    EmpathyLiveSearch *search)
+    TpawLiveSearch *search)
 {
   if (self->priv->search != NULL)
     {
